***** CALCULATIONS OF TARGETS FOR 2015-2020 QUALITY INCENTIVE SCHEME *****

	*The purpose of this do-file is to convert the individual interruption data provided by EDBs into
	*daily and annual non-normalised and normalised SAIFI and SAIDI values in accordance to possible ComCom criteria
	*This is applicable for for years 2015-2020, namely for the new quality incentive scheme 

set more off
cd "INSERT FOLDER DIRECTORY"

foreach edb in "Alpine Energy" "Aurora Energy" "Centralines" "Eastland Network" "Electricity Ashburton" "Electricity Invercargill" "Horizon Energy" ///
	"The Lines Company" "Nelson Electricity" "Network Tasman" "OtagoNet" "Powerco" "Top Energy" "Unison Networks" "Vector Lines" "Wellington Electricity" {

use "alledb_indiv.dta", clear

	keep if edb=="`edb'"

*For clarity rename SAIDI SAIFI so that clear these are the values as provided by the EDB
	rename saidi edb_saidi_indiv
	rename saifi edb_saifi_indiv

*Generating values for SAIDI and SAIFI calculated using customer minutes, customers affected and total ICPs		
	gen cc_saidi_indiv = minutes/icps
	gen cc_saifi_indiv = customers/icps

*Decision made to give planned interruptions given a 50% weighting
	replace cc_saidi_indiv = minutes/icps*0.5 if class=="B"
	replace cc_saifi_indiv = customers/icps*0.5 if class=="B"
		
	*don't need cause
		drop cause

		
*********************************
****   INDIVIDUAL TO DAILY   ****
*********************************

*Aggregating individual interruptions to daily values using CC calcs
	egen cc_saidi_daily = total(cc_saidi_indiv), by(date class)
	egen cc_saifi_daily = total(cc_saifi_indiv), by(date class)

*Only want one daily SAIDI/SAIFI planned/unplanned for each day for each EDB
	bysort edb date class: gen unique = _n==1
	drop if unique==0
	
*Now have the data required for daily SAIDI and SAIFI
*Keep only required and vars for next step. Keep first observation for each day
	keep edb disc_yr date cc_saidi_daily cc_saifi_daily class
	drop if cc_saidi_daily==. & cc_saifi_daily==.
	
*For a complete dataset we want all dates between 1 April 2004 and 31 March 2013 included
*I have pre programmed a dates dta-file with all these dates and can be merged
	merge m:1 date using "dates"
	drop if date > date("31032014","DMY")
	replace edb=edb[_n-1] if edb==""
	sort date

	
**********************************************
***   CALCULATION OF BOUNDARY VALUES   ***
**********************************************

*To calculate the boundary SAIDI and SAIFI values, take the exponential of two components over the reference years.
*The reference years up to 25 March 2014 are the 2005-2009 disclosure years (1 Apr 2004 - 31 Mar 2009).
*The new reference years for the reset are to be the 2005-2014 disclosure years.
*Note that missing values (ie days without an interruption) are not included in the mean or standard deviation below.
	
*1. Natural logs of SAIDI and SAIFI...
	gen lnsaidi = ln(cc_saidi_daily)
	gen lnsaifi = ln(cc_saifi_daily)
	
*2. Average daily log for reference period - Asaidi & Asaifi
	egen Asaidi = mean(lnsaidi) if class=="C"
	egen Asaifi = mean(lnsaifi) if class=="C"
	
*3. Standand deviation of daily logs for reference period - Bsaidi & Bsaifi
	egen Bsaidi = sd(lnsaidi) if class=="C"
	egen Bsaifi = sd(lnsaifi) if class=="C"

*4. Generate average number of unplanned interruptions per year
	egen days_int = count(cc_saidi_daily) if class=="C"
	gen total_days = 3652
	
*5. Generate P-value, probability of interruption on given day in 10-year sample, given the number of actual days of interruptions
	* MED predefined as 2.3 per year on average, and therefore 23 across 10 years
	gen Pvalue = 23 / days_int
	
*6. Generate K-value based off the P-value
	gen Kvalue = -invnormal(Pvalue)

*7. Boundary value equals exp(Asaidi + K x Bsaidi)
	*Our new methodology allows for a customised k-value which takes into account different networks
	*have different expectations for number of interruptions, old methodology assumed 2.5 for everyone.
	gen bound_saidi = exp(Asaidi + Kvalue * Bsaidi)
	gen bound_saifi = exp(Asaifi + Kvalue * Bsaifi)

*Normalise the daily reliability measures
*Replace missing SAIDI and SAIFI (ie days without interruption) with 0
*Replace daily SAIDI/SAIFI with boundary values if a daily value exceeds the boundary value
	gen cc_N_saidi = cc_saidi_daily
	gen cc_N_saifi = cc_saifi_daily

*Decision for the draft is that SAIFI will be the trigger for a major event day, therefore
*boundary values both depend on SAIFI being exceeded.
*Decision for the draft is to replace major event days with the respective SAIDI/SAIFI values
	replace cc_N_saidi = bound_saidi if cc_N_saidi>bound_saidi & cc_N_saifi>bound_saifi & class=="C"
	replace cc_N_saifi = bound_saifi if cc_N_saifi>bound_saifi & class=="C"

*Now that unplanned normalised can bring the SAIDI and SAIFI days together
	egen cc_saidi_Ndaily = total(cc_N_saidi) if cc_N_saidi!=., by(date)
	egen cc_saifi_Ndaily = total(cc_N_saifi) if cc_N_saifi!=., by(date)
	bysort edb date: gen unique = _n==1
	drop if unique==0
	keep edb disc_yr date cc_saidi_Ndaily cc_saifi_Ndaily bound_saidi bound_saifi 

*Save these dailies for each EDB
save "`edb' CC daily", replace
	
	
*******************************************
***           DAILY TO ANNUAL           ***
*******************************************

replace cc_saidi_Ndaily = 0 if cc_saidi_Ndaily==.
replace cc_saifi_Ndaily = 0 if cc_saifi_Ndaily==.

*Use daily data to calculation annual non-normalised and normalised SAIDI/SAIFI
	egen cc_annual_Nsaidi = total(cc_saidi_Ndaily) , by(disc_yr)
	egen cc_annual_Nsaifi = total(cc_saifi_Ndaily) , by(disc_yr)
	
	bysort disc_yr : gen unique = _n==1
	keep if unique==1
	
	keep edb disc_yr cc_annual_Nsaidi cc_annual_Nsaifi
	order edb disc_yr cc_annual_Nsaidi cc_annual_Nsaifi

save "`edb' CC annual", replace
}

clear

*Appending all the daily values generated for all distributors, along with an excel version
foreach edb in "Alpine Energy" "Aurora Energy" "Centralines" "Eastland Network" "Electricity Ashburton" "Electricity Invercargill" "Horizon Energy" ///
	"The Lines Company" "Nelson Electricity" "Network Tasman" "OtagoNet" "Powerco" "Top Energy" "Unison Networks" "Vector Lines" "Wellington Electricity" {

	append using "`edb' CC daily"
}

save daily, replace

*Extracting and saving the boundary values
	
	drop if bound_saidi==. & bound_saifi==.
	bysort edb: gen unique = _n==1
	drop if unique==0	
	keep edb bound_saidi bound_saifi
save boundary, replace

clear

*Appending all the annual values generated for all distributors, along with an excel version
foreach edb in "Alpine Energy" "Aurora Energy" "Centralines" "Eastland Network" "Electricity Ashburton" "Electricity Invercargill" "Horizon Energy" ///
	"The Lines Company" "Nelson Electricity" "Network Tasman" "OtagoNet" "Powerco" "Top Energy" "Unison Networks" "Vector Lines" "Wellington Electricity" {

	append using "`edb' CC annual"
}	

save annual, replace

*Removing temporary edb specific daily and annual values, now that merged into one dataset
foreach edb in "Alpine Energy" "Aurora Energy" "Centralines" "Eastland Network" "Electricity Ashburton" "Electricity Invercargill" "Horizon Energy" ///
	"The Lines Company" "Nelson Electricity" "Network Tasman" "OtagoNet" "Powerco" "Top Energy" "Unison Networks" "Vector Lines" "Wellington Electricity" {
	
	erase "`edb' CC daily.dta"
	erase "`edb' CC annual.dta"
}

	
*Merging the limits as stated by the EDB into the dataset
	use "alledb_annual", clear
	keep edb disc_yr limit_saidi limit_saifi norm_saidi norm_saifi
	rename limit_saidi saidi_limit
	rename limit_saifi saifi_limit
	rename norm_saidi edb_annual_Nsaidi
	rename norm_saifi edb_annual_Nsaifi
	merge 1:1 edb disc_yr using annual.dta
	save temp, replace

*** Scenarios for calculating the target ***

*For the draft decision we have lowered the respective annual values for any breaches that have occured
	gen breach = 0
	
*Listing the distributors and years of breaches
replace breach = 1 if edb=="Aurora Energy" & disc_yr>=2011 & disc_yr<=2012 | edb=="Eastland Network" & disc_yr>=2011 & disc_yr<=2012 | ///
	edb=="Wellington Electricity" & disc_yr>=2012 & disc_yr<=2014 | edb=="Electricity Invercargill" & disc_yr>=2011 & disc_yr<=2012
	
*In dealing with breaches under the new normalisation methodology, we have lowered the annual value
* by the same proportion as the limit was exceeded under the old methodology

*Adjustment made to bring previous breaches down by the same percentage that any limit was exceeded
	gen breach_saidi = saidi_limit / edb_annual_Nsaidi if breach==1
	gen breach_saifi = saifi_limit / edb_annual_Nsaifi if breach==1
	replace cc_annual_Nsaidi = cc_annual_Nsaidi * breach_saidi if breach==1 & breach_saidi<1
	replace cc_annual_Nsaifi = cc_annual_Nsaifi * breach_saifi if breach==1 & breach_saifi<1
	
*Generating the target
	egen saidi_target = mean(cc_annual_Nsaidi), by(edb)
	egen saifi_target = mean(cc_annual_Nsaifi), by(edb)
	
*keep only 1 observation per EDB and target/boundary (add code for caps/collars and incentive rate if required)
	bysort edb: gen unique = _n==1
	drop if unique==0	
	keep edb saidi_target saifi_target
	order edb saidi_target saifi_target
	erase temp.dta

save target, replace


*end
